==> huaweicloudsdkgaussdb-3.1.75-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/list_gauss_my_sql_instance_detail_info_unify_status_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListGaussMySqlInstanceDetailInfoUnifyStatusRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'instance_ids': 'str'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'instance_ids': 'instance_ids'
    }

    def __init__(self, x_language=None, instance_ids=None):
        """ListGaussMySqlInstanceDetailInfoUnifyStatusRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。默认en-us。 取值范围： - en-us - zh-cn
        :type x_language: str
        :param instance_ids: 实例ID，严格匹配UUID规则。最多同时输入20个实例ID，用英文逗号分隔。
        :type instance_ids: str
        """
        
        

        self._x_language = None
        self._instance_ids = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.instance_ids = instance_ids

    @property
    def x_language(self):
        """Gets the x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :return: The x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :param x_language: The x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def instance_ids(self):
        """Gets the instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        实例ID，严格匹配UUID规则。最多同时输入20个实例ID，用英文逗号分隔。

        :return: The instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :rtype: str
        """
        return self._instance_ids

    @instance_ids.setter
    def instance_ids(self, instance_ids):
        """Sets the instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        实例ID，严格匹配UUID规则。最多同时输入20个实例ID，用英文逗号分隔。

        :param instance_ids: The instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :type instance_ids: str
        """
        self._instance_ids = instance_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListGaussMySqlInstanceDetailInfoUnifyStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/list_gauss_my_sql_instance_detail_info_unify_status_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListGaussMySqlInstanceDetailInfoUnifyStatusRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'instance_ids': 'str'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'instance_ids': 'instance_ids'
    }

    def __init__(self, x_language=None, instance_ids=None):
        r"""ListGaussMySqlInstanceDetailInfoUnifyStatusRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。默认en-us。 取值范围： - en-us - zh-cn
        :type x_language: str
        :param instance_ids: 实例ID，严格匹配UUID规则。最多同时输入20个实例ID，用英文逗号分隔。
        :type instance_ids: str
        """
        
        

        self._x_language = None
        self._instance_ids = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.instance_ids = instance_ids

    @property
    def x_language(self):
        r"""Gets the x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :return: The x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        r"""Sets the x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :param x_language: The x_language of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def instance_ids(self):
        r"""Gets the instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        实例ID，严格匹配UUID规则。最多同时输入20个实例ID，用英文逗号分隔。

        :return: The instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :rtype: str
        """
        return self._instance_ids

    @instance_ids.setter
    def instance_ids(self, instance_ids):
        r"""Sets the instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.

        实例ID，严格匹配UUID规则。最多同时输入20个实例ID，用英文逗号分隔。

        :param instance_ids: The instance_ids of this ListGaussMySqlInstanceDetailInfoUnifyStatusRequest.
        :type instance_ids: str
        """
        self._instance_ids = instance_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListGaussMySqlInstanceDetailInfoUnifyStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
